@@ -5,24 +5,24 @@
 #' @param x a vector, matrix or data frame of variables of numeric or factor data types.
 #' @param y a numeric or factor vector with compatible dimsensions to \code{x}.
 #' @param order integer; Controls the number of partial moment quadrant means.  Users are encouraged to try different \code{(order=...)} integer settings with \code{(noise.reduction="off")}.  \code{(order="max")} will force a limit condition perfect fit.
-#' @param s.t.n numeric [0,1]; Signal to noise parameter, sets the threshold of \code{(NNS.dep)} which reduces \code{("order")} when \code{(order=NULL)}.  Defaults to 0.99 to ensure high dependence for higher \code{("order")} and endpoint determination.  \code{(noise.reduction="off")} sets \code{(s.t.n=0)} to allow for maximum fit.
+#' @param stn numeric [0,1]; Signal to noise parameter, sets the threshold of \code{(NNS.dep)} which reduces \code{("order")} when \code{(order=NULL)}.  Defaults to 0.99 to ensure high dependence for higher \code{("order")} and endpoint determination.  \code{(noise.reduction="off")} sets \code{(stn=0)} to allow for maximum fit.
 #' @param type \code{NULL} (default).  To perform logistic regression, set to \code{(type = "LOGIT")}.  To perform a classification, set to \code{(type = "CLASS")}.
 #' @param point.est a numeric or factor vector with compatible dimsensions to \code{x}.  Returns the fitted value \code{y.hat} for any value of \code{x}.
 #' @param location Sets the legend location within the plot, per the \code{x} and \code{y} co-ordinates used in base graphics \link{legend}.
 #' @param return.values logical; \code{TRUE} (default), set to \code{FALSE} in order to only display a regression plot and call values as needed.
 #' @param plot  logical; \code{TRUE} (default) To plot regression.
 #' @param plot.regions logical; \code{FALSE} (default).  Generates 3d regions associated with each regression point for multivariate regressions.  Note, adds significant time to routine.
-#' @param residual.plot logical; \code{TRUE} (default) To plot the \code{y.hat} and \code{Y}.
+#' @param residual.plot logical; \code{TRUE} (default) To plot \code{y.hat} and \code{Y}.
 #' @param threshold  numeric [0,1]; \code{threshold=0} (default) Sets the correlation threshold for independent variables.
-#' @param dep.order \code{NULL} (defualt) integer; Sets the internal \code{order} for \link{NNS.dep}.  Categorical variables typically require \code{dep.order=1}.  Error message will alert user if this is the case.
-#' @param n.best integer; \code{n.best=2} (default) Sets the number of nearest regression points to use in weighting for multivariate regression.  \code{n.best="all"} will select and weight all generated regression points.
+#' @param n.best integer; \code{NULL} (default) Sets the number of nearest regression points to use in weighting for multivariate regression at 2*(# of regressors).  \code{(n.best="all")} will select and weight all generated regression points.  Analogous to \code{k} in \code{k Nearest Neighbors} algorithm and different values are tested using cross-validation in \link{NNS.stack}.
 #' @param noise.reduction the method of determing regression points options: ("mean","median","mode","off"); In low signal:noise situations,\code{(noise.reduction="mean")}  uses means for \link{NNS.dep} restricted partitions, \code{(noise.reduction="median")}  uses medians instead of means for \link{NNS.dep} restricted partitions, while \code{(noise.reduction="mode")}  uses modes instead of means for \link{NNS.dep} restricted partitions.  \code{(noise.reduction="off")}  allows for maximum possible fit with a specific \code{order}.
 #' @param norm \code{NULL} (default) the method of normalization options: ("NNS","std"); Normalizes \code{x} between 0 and 1 for multivariate regression when set to \code{(norm="std")}, or normalizes \code{x} according to \link{NNS.norm} when set to \code{(norm="NNS")}.
-#' @param dist the method of distance calculation; Selects the distance calculation used. \code{dist="L2"} (default) selects the Euclidean distance and \code{dist="L1"} seclects the Manhattan distance.
+#' @param dist options:("L1","L2") the method of distance calculation; Selects the distance calculation used. \code{dist="L2"} (default) selects the Euclidean distance and \code{(dist="L1")} seclects the Manhattan distance.
 #' @param multivariate.call Internal parameter for multivariate regressions.
 #' @return UNIVARIATE regression returns the values:  \code{"Fitted"} for only the fitted values, \code{y.hat}; \code{"Fitted.xy"} for a data frame of \code{x},\code{y} and \code{y.hat}; \code{"derivative"} for the coefficient of the \code{x} and its applicable range;  \code{"partition"} returns the \code{x},\code{y}, \code{"NNS.ID"} assigned to the observation and \code{y.hat}; \code{"Point"} returns the \code{x} point(s) being evaluated; \code{"Point.est"} for the predicted value generated; \code{"Point"} returns the \code{x} point(s) being evaluated; \code{"regression.points"} provides the points used in the regression equation for the given order of partitions; \code{"R2"} provides the goodness of fit; \code{"MSE"} returns the MSE between \code{y} and \code{y.hat}; \code{"Prediction.Accuracy"} returns the correct rounded \code{"Point.est"} used in classifications versus the categorical \code{y}.
 #'
 #' MULTIVARIATE regression returns the values: \code{"Fitted"} for only the fitted values of \code{x}; \code{"Fitted.xy"} for a data frame of \code{y} and fitted values; \code{"RPM"} provides the Regression Point Matrix, the points for each \code{x} used in the regression equation for the given order of partitions; \code{"rhs.partitions"} returns the partition points for each \code{x}; \code{"partition"} returns the \code{x},\code{y}, \code{"NNS.ID"} assigned to the observation and \code{y.hat}; \code{"Point"} returns the \code{x} point(s) being evaluated; \code{"Point.est"} returns the predicted value generated; \code{"equation"} returns the synthetic X* dimension reduction equation.
+#' @note Please ensure \code{point.est} is of compatible dimensions to \code{x}, error message will ensue if not compatible.
 #' @keywords nonlinear regression, classifier
 #' @author Fred Viole, OVVO Financial Systems
 #' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
@@ -71,16 +71,14 @@
 
 NNS.reg = function (x,y,
                     order=NULL,
-                    s.t.n=.99,
+                    stn=.99,
                     type = NULL,
                     point.est = NULL,
                     location = 'top',
                     return.values = TRUE,
-                    plot = TRUE, plot.regions=FALSE,
-                    residual.plot=TRUE,
+                    plot = TRUE, plot.regions=FALSE,residual.plot=TRUE,
                     threshold = 0,
-                    dep.order=NULL,
-                    n.best=2,
+                    n.best=NULL,
                     noise.reduction='mean',
                     norm=NULL,
                     dist="L2",multivariate.call=FALSE){
@@ -90,7 +88,7 @@ NNS.reg = function (x,y,
   original.variable = x
   np = nrow(point.est)
 
-  if(noise.reduction=='off'){s.t.n=0}else{s.t.n=s.t.n}
+  if(noise.reduction=='off'){stn=0}else{stn=stn}
 
 
   if(class(x)=='factor' | class(y)=='factor'){
@@ -102,14 +100,18 @@ NNS.reg = function (x,y,
         if(!is.null(point.est)){point.est=apply(point.est,2,as.numeric)}
         }
     y=as.numeric(y)
-    dep.order=1}
+  }
 
   if(!is.null(ncol(original.variable))){
     if(ncol(original.variable)==1){
       x=original.variable
     } else {
       if(is.null(type)){
-        return(NNS.M.reg(x,y,point.est=point.est,plot=plot,residual.plot=plot,order=order,n.best=n.best,type=type,location=location,noise.reduction=noise.reduction,norm = norm,dist=dist,s.t.n = s.t.n,return.values=return.values,plot.regions = plot.regions))
+        if(!is.null(original.columns)){
+        if(is.null(n.best)){n.best=2*original.columns} else {n.best=n.best}}
+        if(is.null(original.columns)){if(is.null(n.best)){n.best=2} else {n.best=n.best}}
+
+        return(NNS.M.reg(x,y,point.est=point.est,plot=plot,residual.plot=plot,order=order,n.best=n.best,type=type,location=location,noise.reduction=noise.reduction,norm = norm,dist=dist,stn = stn,return.values=return.values,plot.regions = plot.regions))
       } # Multivariate NULL type
       else{
         if(type=="CLASS"){
@@ -180,7 +182,7 @@ NNS.reg = function (x,y,
       dep.reduced.order=order
       }
 
-  if(dependence>s.t.n ){
+  if(dependence>stn ){
     if(is.null(type)){
       part.map = NNS.part(x,y,noise.reduction='off',order=dep.reduced.order)
       if(length(part.map$regression.points$x)==0){
@@ -196,9 +198,9 @@ NNS.reg = function (x,y,
       } else {part.map=part.map
       }
     } # type
-  } # Dependence > s.t.n
+  } # Dependence > stn
 
-  if(dependence<=s.t.n){
+  if(dependence<=stn){
     if(is.null(type)){
       part.map = NNS.part(x,y,noise.reduction=noise.reduction, order=dep.reduced.order,type = "XONLY")
       if(length(part.map$regression.points$x)==0){
@@ -215,7 +217,7 @@ NNS.reg = function (x,y,
       } else {part.map=part.map
       }
     } # type
-  } # Dependence < s.t.n
+  } # Dependence < stn
 
 
   Regression.Coefficients = data.frame(matrix(ncol=3))
@@ -239,12 +241,12 @@ NNS.reg = function (x,y,
 
   ###Endpoints
   if(length(x[x<min.range])>0){
-    if(dependence<s.t.n){
+    if(dependence<stn){
       x0 = Dynamic.average.min} else {
         x0 = unique(y[x==min(x)])} }  else {x0 = unique(y[x==min(x)])}
 
   if(length(x[x>max.range])>0){
-    if(dependence<s.t.n){x.max = Dynamic.average.max} else {x.max = unique(y[x==max(x)])}}  else { x.max = unique(y[x==max(x)])}
+    if(dependence<stn){x.max = Dynamic.average.max} else {x.max = unique(y[x==max(x)])}}  else { x.max = unique(y[x==max(x)])}
 
 
   regression.points=rbindlist(list(regression.points,list(max(x),mean(x.max))))
@@ -300,14 +302,14 @@ NNS.reg = function (x,y,
   if(is.na(Regression.Coefficients[1,Coefficient])){Regression.Coefficients[1,Coefficient:= Regression.Coefficients[2,Coefficient] ]}
   if(is.na(Regression.Coefficients[.N,Coefficient])){Regression.Coefficients[.N,Coefficient:= Regression.Coefficients[.N-1,Coefficient] ]}
 
-  coef.interval=findInterval(x,Regression.Coefficients[,(X.Lower.Range)],left.open = F)
-  reg.interval=findInterval(x,regression.points[,x],left.open = F)
+  coef.interval=findInterval(x,Regression.Coefficients[,(X.Lower.Range)],left.open = FALSE)
+  reg.interval=findInterval(x,regression.points[,x],left.open = FALSE)
 
   estimate=((x- regression.points[reg.interval,x])*Regression.Coefficients[coef.interval,Coefficient])+regression.points[reg.interval,y]
 
   if(!is.null(point.est)){
-  coef.point.interval=findInterval(point.est,Regression.Coefficients[,(X.Lower.Range)],left.open = F)
-  reg.point.interval=findInterval(point.est,regression.points[,x],left.open=F)
+  coef.point.interval=findInterval(point.est,Regression.Coefficients[,(X.Lower.Range)],left.open = FALSE)
+  reg.point.interval=findInterval(point.est,regression.points[,x],left.open=FALSE)
   coef.point.interval[coef.point.interval==0]<- 1
   reg.point.interval[reg.point.interval==0]<- 1
   point.est.y=((point.est - regression.points[reg.point.interval,x])*Regression.Coefficients[coef.point.interval,Coefficient])+regression.points[reg.point.interval,y]
