@@ -1,8 +1,8 @@
 #' NNS TSD Test
 #'
 #' Bi-directional test of third degree stochastic dominance using lower partial moments.
-#' @param x variable
-#' @param y variable
+#' @param x a numeric vector.
+#' @param y a numeric vector.
 #' @return Returns one of the following TSD results: \code{"X TSD Y"}, \code{"Y TSD X"}, or \code{"NO TSD EXISTS"}.
 #' @keywords stochastic dominance
 #' @author Fred Viole, OVVO Financial Systems
@@ -21,31 +21,12 @@ NNS.TSD <- function(x,y){
   Combined = c(x_sort,y_sort)
   Combined_sort = sort(Combined, decreasing=FALSE)
 
-  LPM_x_sort = numeric(0)
-  LPM_y_sort = numeric(0)
+  x.tsd.y=sum((LPM(2,Combined_sort,y)-LPM(2,Combined_sort,x))>=0)
 
-  output_x <- vector("numeric", length(x))
-  output_y <- vector("numeric", length(x))
+  y.tsd.x=sum((LPM(2,Combined_sort,x)-LPM(2,Combined_sort,y))>=0)
 
-
-  for (i in 1:length(Combined)){
-
-    if(LPM(2,Combined_sort[i],y)-LPM(2,Combined_sort[i],x)>=0 )
-    {output_x[i]<-0} else { break }}
-
-  for (i in 1:length(Combined)){
-
-    if(LPM(2,Combined_sort[i],x)-LPM(2,Combined_sort[i],y)>=0 )
-    {output_y[i]<-0} else { break }
-
-  }
-
-
-
-  for (j in 1:length(Combined_sort)){
-    LPM_x_sort[j] = LPM(2,Combined_sort[j],x)
-    LPM_y_sort[j] = LPM(2,Combined_sort[j],y)
-  }
+  LPM_x_sort=LPM(2,Combined_sort,x)
+  LPM_y_sort=LPM(2,Combined_sort,y)
 
   plot(LPM_x_sort, type = "l", lwd =3,col = "red", main = "TSD", ylab = "Area of Cumulative Distribution",
        ylim = c(min(c(LPM_y_sort,LPM_x_sort)),max(c(LPM_y_sort,LPM_x_sort))))
@@ -53,7 +34,7 @@ NNS.TSD <- function(x,y){
   legend("topleft", c("X","Y"), lwd=10,
          col=c("red","blue"))
 
-   ifelse (length(output_x)==length(Combined) & min(x)>=min(y) & mean(x)>=mean(y),"X TSD Y",
-          ifelse (length(output_y)==length(Combined) & min(y)>=min(x)& mean(y)>=mean(x),"Y TSD X","NO TSD EXISTS"))
+   ifelse (x.tsd.y==length(Combined) & min(x)>=min(y) & mean(x)>=mean(y),"X TSD Y",
+          ifelse (y.tsd.x==length(Combined) & min(y)>=min(x)& mean(y)>=mean(x),"Y TSD X","NO TSD EXISTS"))
 }
 
